@@ -1,6 +1,6 @@
 package Catmandu::HTML;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 1;
 
@@ -20,6 +20,18 @@ Command line client C<catmandu>:
 
   catmandu convert JSON to HTML < data/test.json > ex/test.html
 
+  # Keep the text
+  curl -s http://librecat.org |
+    catmandu convert HTML to Text --fix "html_text()"
+
+  # Filter out the anchors
+  curl -s http://librecat.org |
+    catmandu convert HTML to Text --fix "html_filter_tag(a); html_text(join:\"\n\")"
+
+  # Filter out the meta tags as YAML
+  curl -s http://librecat.org |
+    catmandu convert HTML to YAML --fix "html_filter_tag(meta, group_by:name)"
+
 See documentation of modules for more examples.
 
 =head1 AVAILABLE MODULES
@@ -36,7 +48,15 @@ Parse HTML data
 
 =item L<Catmandu::Fix::html_filter_tag>
 
-Filter HTML tags and optional group them
+Filter HTML by name and optional group them
+
+=item L<Catmandu::Fix::html_filter_type>
+
+Filter HTML by type
+
+=item L<Catmandu::Fix::html_text>
+
+Select only the literal text values from the HTML
 
 =back
 
